@@ -36,9 +36,9 @@ IntegerVector get_cluster_matrix(NumericMatrix distribution, double threshold, S
       for(int rowi = 0; rowi < res.nrow(); rowi++){
         acc = 0;
         for(int coli = 0; coli < res.ncol(); coli++){
-          if((coli==0)||(distribution(rowi,coli)<threshold)){
+          if((coli==0)|(distribution(rowi,coli)<threshold)){
             res(rowi,coli) = 0;
-          }else if((coli>0) && (distribution(rowi,coli)>threshold)){
+          }else if((coli>0) & (distribution(rowi,coli)>threshold)){
             if(distribution(rowi,coli-1)<threshold){
               acc ++;
             }
@@ -55,7 +55,7 @@ IntegerVector get_cluster_matrix(NumericMatrix distribution, double threshold, S
     if(side == "ending"){
       for(int rowi = 0; rowi < res.nrow(); rowi++){
         int coli = res.ncol()-1;
-        while((res(rowi,coli)>0)&&(coli>0)){
+        while((res(rowi,coli)>0)&(coli>0)){
           res(rowi,coli)=0;
           coli = coli-1;
         }
@@ -156,7 +156,7 @@ IntegerMatrix get_clusterdepth_tail(IntegerMatrix cluster, String border){
   if(border == "rm"){
     for(int rowi = 0; rowi < res.nrow(); rowi++){
       int coli = res.ncol()-1;
-      while( (res(rowi,abs(coli))>0)&&(coli>=0)){
+      while( (res(rowi,abs(coli))>0)&(coli>=0)){
         res(rowi,coli)=0;
         coli = coli-1;
       }
